RifleTokyoOL: RifleTokyoOL

RifleTokyoOLR Documentation

RifleTokyoOL

Description

The data to be used are results from Tokyo Olympics, 50-mter rifle in three positions. The shooters (i.e. athletes) competes in three different shooting positions (styles), (i) kneeling ("kne" in Norwegian), (ii) prone ("liggende" in Norwegian) and (iii) standing position. In the final with 8 athletes, the athletes shoot three five-shot series in each position, with maximum score 54,5 points in each series.

Usage

RifleTokyoOL

Format

#' #'

Points

(real number) The total number of points in a 5 shot series.

Style

(Textstring) Three possible styles

Gender

(Textstring) Two genders: males and female

Athlete

(Textstring) Name of the athlete

Simulated

(Text string) Yes or No.

Examples

lm(Points ~ Style, data = RifleTokyoOL)

nganbaohuynh/stat210 documentation built on Aug. 20, 2022, 10:08 p.m.