| RifleTokyoOL | R Documentation |
The data to be used are results from Tokyo Olympics, 50-mter rifle in three positions. The shooters (i.e. athletes) competes in three different shooting positions (styles), (i) kneeling ("kne" in Norwegian), (ii) prone ("liggende" in Norwegian) and (iii) standing position. In the final with 8 athletes, the athletes shoot three five-shot series in each position, with maximum score 54,5 points in each series.
RifleTokyoOL
#' #'
(real number) The total number of points in a 5 shot series.
(Textstring) Three possible styles
(Textstring) Two genders: males and female
(Textstring) Name of the athlete
(Text string) Yes or No.
lm(Points ~ Style, data = RifleTokyoOL)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.